@@ -10,4 +10,8 @@ class CustomUser(AbstractUser):
     extra_field = models.CharField(max_length=2)
     new_username_field = models.CharField(unique=True, max_length=20)
 
-    USERNAME_FIELD = 'new_username_field'
\ No newline at end of file
+    USERNAME_FIELD = 'new_username_field'
+
+    def save(self, *args, **kwargs):
+        self.new_username_field = self.username
+        super(CustomUser, self).save(*args, **kwargs)
